==> senior_design_system-0.21.4.tar.gz: example/lib/pages/action_button.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class ActionButtonExample extends StatefulWidget {
  const ActionButtonExample({Key? key}) : super(key: key);

  @override
  _ActionButtonExampleState createState() => _ActionButtonExampleState();
}

class _ActionButtonExampleState extends State<ActionButtonExample> {
  bool _lockStateOne = false;
  bool _lockStateTwo = false;
  bool _lockStateThree = false;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Action Button Example',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(32.0),
          child: Column(
            children: [
              Panel(
                title: 'Small',
                child: SeniorActionButton(
                  icon: _lockStateOne ? FontAwesomeIcons.lock : FontAwesomeIcons.lockOpen,
                  size: SeniorActionButtonSize.small,
                  onTap: () {
                    setState(() {
                      _lockStateOne = !_lockStateOne;
                    });
                  },
                ),
              ),
              Panel(
                title: 'Medium',
                child: SeniorActionButton(
                  icon: _lockStateTwo ? FontAwesomeIcons.lock : FontAwesomeIcons.lockOpen,
                  onTap: () {
                    setState(() {
                      _lockStateTwo = !_lockStateTwo;
                    });
                  },
                ),
              ),
              Panel(
                title: 'Press',
                child: SeniorActionButton.press(
                  icon: _lockStateThree ? FontAwesomeIcons.lock : FontAwesomeIcons.lockOpen,
                  onTap: () {
                    setState(() {
                      _lockStateThree = !_lockStateThree;
                    });
                  },
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-0.26.2.tar.gz: example/lib/pages/action_button.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class ActionButtonExample extends StatefulWidget {
  const ActionButtonExample({Key? key}) : super(key: key);

  @override
  _ActionButtonExampleState createState() => _ActionButtonExampleState();
}

class _ActionButtonExampleState extends State<ActionButtonExample> {
  bool _lockStateOne = false;
  bool _lockStateTwo = false;
  bool _lockStateThree = false;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Action Button Example',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(32.0),
          child: Column(
            children: [
              Panel(
                title: 'Small',
                child: SeniorActionButton(
                  icon: _lockStateOne
                      ? FontAwesomeIcons.lock
                      : FontAwesomeIcons.lockOpen,
                  size: SeniorActionButtonSize.small,
                  onTap: () {
                    setState(() {
                      _lockStateOne = !_lockStateOne;
                    });
                  },
                ),
              ),
              Panel(
                title: 'Medium',
                child: SeniorActionButton(
                  icon: _lockStateTwo
                      ? FontAwesomeIcons.lock
                      : FontAwesomeIcons.lockOpen,
                  onTap: () {
                    setState(() {
                      _lockStateTwo = !_lockStateTwo;
                    });
                  },
                ),
              ),
              Panel(
                title: 'Press',
                child: SeniorActionButton.press(
                  icon: _lockStateThree
                      ? FontAwesomeIcons.lock
                      : FontAwesomeIcons.lockOpen,
                  onTap: () {
                    setState(() {
                      _lockStateThree = !_lockStateThree;
                    });
                  },
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
